@@ -17,8 +17,8 @@ void KbfxConfigDlgThemes::init()
 	KbfxFormReady = FALSE;
 	img_nopreview = image0;
 
-	connect ( this, TQT_SIGNAL ( KbfxThemeDoInstall ( TQString & ) ),
-	          this, TQT_SLOT ( KbfxThemeInstall ( TQString & ) ) );
+	connect ( this, TQ_SIGNAL ( KbfxThemeDoInstall ( TQString & ) ),
+	          this, TQ_SLOT ( KbfxThemeInstall ( TQString & ) ) );
 }
 
 /*
