@@ -45,7 +45,7 @@ KBFXFontChooser::KBFXFontChooser ( TQWidget *parent, const char *name )
 	                          3 * KDialog::spacingHint() + pixmap.width() );
 	layout->addWidget ( m_button );
 
-	connect ( m_button, TQT_SIGNAL ( clicked() ), this, TQT_SLOT ( buttonClicked() ) );
+	connect ( m_button, TQ_SIGNAL ( clicked() ), this, TQ_SLOT ( buttonClicked() ) );
 
 	updateFontLabel();
 
