@@ -43,8 +43,8 @@ KbfxPlasmaIndexView::KbfxPlasmaIndexView ( TQWidget * parent, const char *name,
 	m_currentItem = 0L;
 	m_selectedItem = 0L;
 //	m_pluginList = "";
-	connect ( this, TQT_SIGNAL ( clicked ( KbfxPlasmaIndexItem * ) ), this,
-	          TQT_SLOT ( slotClicked ( KbfxPlasmaIndexItem * ) ) );
+	connect ( this, TQ_SIGNAL ( clicked ( KbfxPlasmaIndexItem * ) ), this,
+	          TQ_SLOT ( slotClicked ( KbfxPlasmaIndexItem * ) ) );
 	m_currentView = 0;
 	setDragAutoScroll ( true );
 }
@@ -61,8 +61,8 @@ KbfxPlasmaIndexView::checkMousePos ()
 	if ( TQCursor::pos () == mapToGlobal ( contentsToViewport ( m_currentPos ) ) )
 	{
 		TQMouseEvent me ( TQEvent::MouseButtonPress,
-		                 this->mapToGlobal ( m_currentPos ), Qt::LeftButton,
-		                 Qt::LeftButton );
+		                 this->mapToGlobal ( m_currentPos ), TQt::LeftButton,
+		                 TQt::LeftButton );
 
 		clearAll ();
 
@@ -167,8 +167,8 @@ KbfxPlasmaIndexView::contentsContextMenuEvent ( TQContextMenuEvent * event )
 	event = event;
 /*
 	m_pluginMenu = new TDEPopupMenu ( this );;
-	connect ( m_pluginMenu, TQT_SIGNAL ( activated ( int ) ), this,
-	          TQT_SLOT ( contextMenuSlot ( int ) ) );
+	connect ( m_pluginMenu, TQ_SIGNAL ( activated ( int ) ), this,
+	          TQ_SLOT ( contextMenuSlot ( int ) ) );
 
 	m_pluginMenu->insertTitle ( "Insert Plugin", 0, 0 );
 	int _index = 1;
@@ -317,7 +317,7 @@ KbfxPlasmaIndexView::contentsMouseMoveEvent ( TQMouseEvent * me )
 
 	this->setCursor ( TQCursor ( TQt::PointingHandCursor ) );
 
-	TQTimer::singleShot ( 800, this, TQT_SLOT ( checkMousePos () ) );
+	TQTimer::singleShot ( 800, this, TQ_SLOT ( checkMousePos () ) );
 
 	if ( contentsToViewport ( me->pos () ).y () < this->height () / 5 )
 	{
@@ -360,7 +360,7 @@ KbfxPlasmaIndexView::contentsMouseMoveEvent ( TQMouseEvent * me )
 void
 KbfxPlasmaIndexView::contentsMousePressEvent ( TQMouseEvent * me )
 {
-	if ( me->button () == Qt::RightButton )
+	if ( me->button () == TQt::RightButton )
 		return;
 
 	clearAll ();
